
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.31.0rc2',
    'branch_nick': 'build-1.31.0rc2',
    'revision_id': 'bc71856931bf8384fb6715b1ae977a32ef30a0ac',
    'revno': 12459
}
